<?php
/**
 * Functions which enhance the theme.
 *
 * @package marie
 */

/**
 * Determines if post thumbnail can be displayed.
 *
 * @return bool
 */
function marie_can_show_post_thumbnail() {
	return apply_filters(
		'marie_can_show_post_thumbnail',
		! post_password_required() && ! is_attachment() && has_post_thumbnail()
	);
}


if ( ! function_exists( 'marie_post_thumbnail' ) ) {
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 * Adapted from Twenty Twenty-One Theme Theme.
	 *
	 * @since 1.0.0
	 * @param string $size size of post thumbnail 'thumb', 'medium', 'medium_large' etc.
	 * @return void
	 */
	function marie_post_thumbnail( $size = 'medium' ) {
		if ( ! marie_can_show_post_thumbnail() ) {
			return;
		}
		?>

		<?php if ( is_singular() ) : ?>

			<figure class="post-thumbnail">
				<?php
				// Thumbnail is loaded eagerly because it's going to be in the viewport immediately.
				the_post_thumbnail( $size, array( 'loading' => 'eager' ) );
				?>
				<?php if ( wp_get_attachment_caption( get_post_thumbnail_id() ) ) : ?>
					<figcaption><?php echo wp_kses_post( wp_get_attachment_caption( get_post_thumbnail_id() ) ); ?></figcaption>
				<?php endif; ?>
			</figure><!-- .post-thumbnail -->

		<?php else : ?>

			<figure class="post-thumbnail">
				<a href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
					<?php the_post_thumbnail( $size ); ?>
				</a>
				<?php if ( wp_get_attachment_caption( get_post_thumbnail_id() ) ) : ?>
					<figcaption class="screen-reader-text"><?php echo wp_kses_post( wp_get_attachment_caption( get_post_thumbnail_id() ) ); ?></figcaption>
				<?php endif; ?>
			</figure>

		<?php endif; ?>
		<?php
	}
}

/**
 * Add a button to top-level menu items that has sub-menus.
 * An icon is added using CSS depending on the value of aria-expanded.
 * Adapted from Twenty-Twentyone Theme
 *
 * @param string $output Nav menu item start element.
 * @param object $item   Nav menu item.
 * @param int    $depth  Depth.
 * @param object $args   Nav menu args.
 *
 * @return string Nav menu item start element.
 */
function marie_add_sub_menu_toggle( $output, $item, $depth, $args ) {
	// Do not render sub menu toggles if nav menu is shown via the 'Navigation Menu' widget. See intercept_widget_nav_menu_args.
	$is_nav_rendering_via_navigation_widget = false;
	if ( property_exists( $args, 'is_widget' ) ) {
		$is_nav_rendering_via_navigation_widget = $args->is_widget;
	}
	if ( $is_nav_rendering_via_navigation_widget ) {
		return $output;
	}
	if ( in_array( 'menu-item-has-children', $item->classes, true ) ) {
		$btn_title = esc_html__( 'Open ', 'marie' ) . $item->title . esc_html__( ' submenu', 'marie' );
		// Add toggle button.
		$output .= '<button class="sub-menu-toggle" aria-expanded="false">';
		$output .= '<span aria-hidden="true" class="icon-plus"></span>';
		$output .= '<span aria-hidden="true" class="icon-minus"></span>';
		$output .= '<span class="screen-reader-text">' . $btn_title . '</span>';
		$output .= '</button>';
	}
	return $output;
}
add_filter( 'walker_nav_menu_start_el', 'marie_add_sub_menu_toggle', 10, 4 );

/**
 * Intercept the default more "[...]" after excerpt and replace with empty string.
 *
 * @param string $more The default more [...].
 */
function marie_excerpt_more( $more ) {
	if ( is_admin() ) {
		return $more;
	}
	return '';
}
add_filter( 'excerpt_more', 'marie_excerpt_more' );


/**
 * If a nav menu is being rendered via wp 'navigation widget' we don't want to show the sub menu toggles because they won't work. marie_add_sub_menu_toggle will check 'is_widget' and only render the toggles if it is NOT.
 *
 * Note sub-menu-toggles are hidden with css in footer, should use same approach for both...
 *
 * @param array $args - what is passed to marie_add_sub_menu_toggle().
 */
function marie_intercept_widget_nav_menu_args( $args ) {
	return array_merge(
		$args,
		array(
			'is_widget' => true,
		)
	);

}
add_filter( 'widget_nav_menu_args', 'marie_intercept_widget_nav_menu_args' );


/**
 * Socials menu is managed with WordPress menus. We need to intercept wp_nav_menu, replace the link text with a <span>, set background-image of the span to an encoded svg, also add a span.screen-reader-text containing the link text.
 *
 * See twentytwenty_nav_menu_social_icons for a non quick and filthy version of this.
 *
 * @param string   $item_output - html to render the <a>link text</a>.
 * @param WP_Post  $item - Menu item.
 * @param int      $depth - depth.
 * @param stdClass $args wp_nav_menu args.
 */
function marie_intercept_social_nav_to_add_icons( $item_output, $item, $depth, $args ) {
	// Change SVG icon inside social links menu if there is supported URL.

	// use js console.log(encodeURI('<svg></svg>')); to get these.
	// ctrl+f '10596d' to change $teal hex color.
	$temp_encoded_svgs = array(
		'link'      => 'data:image/svg+xml;utf8,%3Csvg%20class=%22svg-icon%22%20xmlns=%22http://www.w3.org/2000/svg%22%20width=%2224%22%20height=%2224%22%20viewBox=%220%200%2018%2018%22%3E%3Cpath%20fill=%22%2310596d%22%20d=%22M6.70846497,10.3082552%20C6.43780491,9.94641406%206.5117218,9.43367048%206.87356298,9.16301045%20C7.23540415,8.89235035%207.74814771,8.96626726%208.01880776,9.32810842%20C8.5875786,10.0884893%209.45856383,10.5643487%2010.4057058,10.6321812%20C11.3528479,10.7000136%2012.2827563,10.3531306%2012.9541853,9.68145807%20L15.3987642,7.23705399%20C16.6390369,5.9529049%2016.6212992,3.91168563%2015.3588977,2.6492841%20C14.0964962,1.38688258%2012.0552769,1.36914494%2010.77958,2.60113525%20L9.37230725,4.00022615%20C9.05185726,4.31881314%208.53381538,4.31730281%208.21522839,3.99685275%20C7.89664141,3.67640269%207.89815174,3.15836082%208.21860184,2.83977385%20L9.63432671,1.43240056%20C11.5605503,-0.42800847%2014.6223793,-0.401402004%2016.5159816,1.49220028%20C18.4095838,3.38580256%2018.4361903,6.44763148%2016.5658147,8.38399647%20L14.1113741,10.838437%20C13.1043877,11.8457885%2011.7095252,12.366113%2010.2888121,12.2643643%20C8.86809903,12.1626156%207.56162126,11.4488264%206.70846497,10.3082552%20Z%20M11.291535,7.6917448%20C11.5621951,8.05358597%2011.4882782,8.56632952%2011.126437,8.83698955%20C10.7645959,9.10764965%2010.2518523,9.03373274%209.98119227,8.67189158%20C9.4124214,7.91151075%208.54143617,7.43565129%207.59429414,7.36781884%20C6.6471521,7.29998638%205.71724372,7.64686937%205.04581464,8.31854193%20L2.60123581,10.762946%20C1.36096312,12.0470951%201.37870076,14.0883144%202.64110228,15.3507159%20C3.90350381,16.6131174%205.94472309,16.630855%207.21873082,15.400549%20L8.61782171,14.0014581%20C8.93734159,13.6819382%209.45538568,13.6819382%209.77490556,14.0014581%20C10.0944254,14.320978%2010.0944254,14.839022%209.77490556,15.1585419%20L8.36567329,16.5675994%20C6.43944966,18.4280085%203.37762074,18.401402%201.48401846,16.5077998%20C-0.409583822,14.6141975%20-0.436190288,11.5523685%201.43418536,9.61600353%20L3.88862594,7.16156298%20C4.89561225,6.15421151%206.29047483,5.63388702%207.71118789,5.7356357%20C9.13190097,5.83738438%2010.4383788,6.55117356%2011.291535,7.6917448%20Z%22%3E%3C/path%3E%3C/svg%3E',
		'facebook'  => 'data:image/svg+xml;utf8,%3Csvg%20width=%2224%22%20height=%2224%22%20viewBox=%220%200%2024%2024%22%20xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath%20fill=%22%2310596d%22%20d=%22M12%202C6.5%202%202%206.5%202%2012c0%205%203.7%209.1%208.4%209.9v-7H7.9V12h2.5V9.8c0-2.5%201.5-3.9%203.8-3.9%201.1%200%202.2.2%202.2.2v2.5h-1.3c-1.2%200-1.6.8-1.6%201.6V12h2.8l-.4%202.9h-2.3v7C18.3%2021.1%2022%2017%2022%2012c0-5.5-4.5-10-10-10z%22%3E%3C/path%3E%3C/svg%3E',
		'twitter'   => 'data:image/svg+xml;utf8,%3Csvg%20class=%22svg-icon%22%20viewBox=%220%200%2024%2024%22%20xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath%20fill=%22%2310596d%22%20d=%22M22.23,5.924c-0.736,0.326-1.527,0.547-2.357,0.646c0.847-0.508,1.498-1.312,1.804-2.27%20c-0.793,0.47-1.671,0.812-2.606,0.996C18.324,4.498,17.257,4,16.077,4c-2.266,0-4.103,1.837-4.103,4.103%20c0,0.322,0.036,0.635,0.106,0.935C8.67,8.867,5.647,7.234,3.623,4.751C3.27,5.357,3.067,6.062,3.067,6.814%20c0,1.424,0.724,2.679,1.825,3.415c-0.673-0.021-1.305-0.206-1.859-0.513c0,0.017,0,0.034,0,0.052c0,1.988,1.414,3.647,3.292,4.023%20c-0.344,0.094-0.707,0.144-1.081,0.144c-0.264,0-0.521-0.026-0.772-0.074c0.522,1.63,2.038,2.816,3.833,2.85%20c-1.404,1.1-3.174,1.756-5.096,1.756c-0.331,0-0.658-0.019-0.979-0.057c1.816,1.164,3.973,1.843,6.29,1.843%20c7.547,0,11.675-6.252,11.675-11.675c0-0.178-0.004-0.355-0.012-0.531C20.985,7.47,21.68,6.747,22.23,5.924z%22%3E%3C/path%3E%3C/svg%3E',
		'youtube'   => 'data:image/svg+xml;utf8,%3Csvg%20class=%22svg-icon%22%20width=%2224%22%20height=%2224%22%20viewBox=%220%200%2024%2024%22%20xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath%20fill=%22%2310596d%22%20d=%22M21.8,8.001c0,0-0.195-1.378-0.795-1.985c-0.76-0.797-1.613-0.801-2.004-0.847c-2.799-0.202-6.997-0.202-6.997-0.202%20h-0.009c0,0-4.198,0-6.997,0.202C4.608,5.216,3.756,5.22,2.995,6.016C2.395,6.623,2.2,8.001,2.2,8.001S2,9.62,2,11.238v1.517%20c0,1.618,0.2,3.237,0.2,3.237s0.195,1.378,0.795,1.985c0.761,0.797,1.76,0.771,2.205,0.855c1.6,0.153,6.8,0.201,6.8,0.201%20s4.203-0.006,7.001-0.209c0.391-0.047,1.243-0.051,2.004-0.847c0.6-0.607,0.795-1.985,0.795-1.985s0.2-1.618,0.2-3.237v-1.517%20C22,9.62,21.8,8.001,21.8,8.001z%20M9.935,14.594l-0.001-5.62l5.404,2.82L9.935,14.594z%22%3E%3C/path%3E%3C/svg%3E',
		'instagram' => 'data:image/svg+xml;utf8,%3Csvg%20width=%2224%22%20height=%2224%22%20viewBox=%220%200%2024%2024%22%20version=%221.1%22%20xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath%20fill=%22%2310596d%22%20d=%22M12,4.622c2.403,0,2.688,0.009,3.637,0.052c0.877,0.04,1.354,0.187,1.671,0.31c0.42,0.163,0.72,0.358,1.035,0.673%20c0.315,0.315,0.51,0.615,0.673,1.035c0.123,0.317,0.27,0.794,0.31,1.671c0.043,0.949,0.052,1.234,0.052,3.637%20s-0.009,2.688-0.052,3.637c-0.04,0.877-0.187,1.354-0.31,1.671c-0.163,0.42-0.358,0.72-0.673,1.035%20c-0.315,0.315-0.615,0.51-1.035,0.673c-0.317,0.123-0.794,0.27-1.671,0.31c-0.949,0.043-1.233,0.052-3.637,0.052%20s-2.688-0.009-3.637-0.052c-0.877-0.04-1.354-0.187-1.671-0.31c-0.42-0.163-0.72-0.358-1.035-0.673%20c-0.315-0.315-0.51-0.615-0.673-1.035c-0.123-0.317-0.27-0.794-0.31-1.671C4.631,14.688,4.622,14.403,4.622,12%20s0.009-2.688,0.052-3.637c0.04-0.877,0.187-1.354,0.31-1.671c0.163-0.42,0.358-0.72,0.673-1.035%20c0.315-0.315,0.615-0.51,1.035-0.673c0.317-0.123,0.794-0.27,1.671-0.31C9.312,4.631,9.597,4.622,12,4.622%20M12,3%20C9.556,3,9.249,3.01,8.289,3.054C7.331,3.098,6.677,3.25,6.105,3.472C5.513,3.702,5.011,4.01,4.511,4.511%20c-0.5,0.5-0.808,1.002-1.038,1.594C3.25,6.677,3.098,7.331,3.054,8.289C3.01,9.249,3,9.556,3,12c0,2.444,0.01,2.751,0.054,3.711%20c0.044,0.958,0.196,1.612,0.418,2.185c0.23,0.592,0.538,1.094,1.038,1.594c0.5,0.5,1.002,0.808,1.594,1.038%20c0.572,0.222,1.227,0.375,2.185,0.418C9.249,20.99,9.556,21,12,21s2.751-0.01,3.711-0.054c0.958-0.044,1.612-0.196,2.185-0.418%20c0.592-0.23,1.094-0.538,1.594-1.038c0.5-0.5,0.808-1.002,1.038-1.594c0.222-0.572,0.375-1.227,0.418-2.185%20C20.99,14.751,21,14.444,21,12s-0.01-2.751-0.054-3.711c-0.044-0.958-0.196-1.612-0.418-2.185c-0.23-0.592-0.538-1.094-1.038-1.594%20c-0.5-0.5-1.002-0.808-1.594-1.038c-0.572-0.222-1.227-0.375-2.185-0.418C14.751,3.01,14.444,3,12,3L12,3z%20M12,7.378%20c-2.552,0-4.622,2.069-4.622,4.622S9.448,16.622,12,16.622s4.622-2.069,4.622-4.622S14.552,7.378,12,7.378z%20M12,15%20c-1.657,0-3-1.343-3-3s1.343-3,3-3s3,1.343,3,3S13.657,15,12,15z%20M16.804,6.116c-0.596,0-1.08,0.484-1.08,1.08%20s0.484,1.08,1.08,1.08c0.596,0,1.08-0.484,1.08-1.08S17.401,6.116,16.804,6.116z%22%3E%3C/path%3E%3C/svg%3E',
	);

	// Only for the socials menu.
	if ( 'socials-header' === $args->theme_location || 'socials-footer' === $args->theme_location ) {

		// theme only has 4 icons - facebook, twitter, instagram, youtube. Use link icon as default for other links.
		$this_social_icon = 'link';

		// Change from the default icon only if social link includes one of our 4 icons.
		if ( strpos( $item->url, 'facebook.com' ) ) {
			$this_social_icon = 'facebook';
		}
		if ( strpos( $item->url, 'twitter.com' ) ) {
			$this_social_icon = 'twitter';
		}
		if ( strpos( $item->url, 'youtube.com' ) ) {
			$this_social_icon = 'youtube';
		}
		if ( strpos( $item->url, 'instagram.com' ) ) {
			$this_social_icon = 'instagram';
		}

		// Get the appropiate encoded social icon.
		$encoded_icon = $temp_encoded_svgs['link'];
		if ( array_key_exists( $this_social_icon, $temp_encoded_svgs ) ) {
			$encoded_icon = $temp_encoded_svgs[ $this_social_icon ];
		}

		// Add the social icon (span textcontent is empty so not announced on NVDA, aria-hidden maybe not needed?) and open a screen-reader-text span before the link text. The span is closed via wp_nav_menu 'link_after' => '</span>'.
		$item_output = str_replace( $args->link_before, '<span aria-hidden="true" style="width:2rem;height:2rem;display:block;background-size:cover;background-repeat:no-repeat;background-image: url(' . $encoded_icon . ');" class="marie-icon-sidebar marie-svg-icon marie-socials-' . $this_social_icon . '"></span><span class="screen-reader-text">', $item_output );

	}

	return $item_output;
}

add_filter( 'walker_nav_menu_start_el', 'marie_intercept_social_nav_to_add_icons', 10, 4 );
