/* eslint-disable object-shorthand */
import { navigationUtil } from './util';

const {
	getIsOutermost,
	toggleAriaExpanded,
	closeMenu,
	openMenu,
	removeNavSubItemsFromTabOrder,

} = navigationUtil;

export const navigationHandlers = {

	/**
	 * Closes the mobile menu if a cusotm anchor link on the same page is clicked.
	 */
	handleCloseMobileNavOnAnchorLinkClicked: function() {
		const menu = document.querySelector( '#marie-main-nav' );
		const togglerButton = document.querySelector( '.marie-burger-btn' );

		if ( ! menu || ! menu.classList.contains( 'show' ) ) {
			return;
		}
		menu.classList.remove( 'show' );

		// Also change burger/minimise icon.
		const burgerIcon = document.querySelector( '.marie-burger-btn' );
		if ( ! burgerIcon ) {
			return;
		}
		if ( burgerIcon.classList.contains( 'nav-open' ) ) {
			burgerIcon.classList.remove( 'nav-open' );
			togglerButton.setAttribute( 'aria-expanded', false );
		}

		const header = document.querySelector( 'header#marie-main-header' );
		if ( ! header ) {
			return;
		}
		if ( header.classList.contains( 'nav-open' ) ) {
			header.classList.remove( 'nav-open' );
		}
	},

	/**
	 * Toggle the mobile menu.
	 */
	handleToggleMobileMenu: function() {
		const menu = document.querySelector( '#marie-main-nav' );
		const header = document.getElementById( 'marie-main-header' );

		if ( ! menu || ! header ) {
			return;
		}

		if ( ! menu.classList.contains( 'show' ) ) {
			openMenu( this, menu, header );
		} else {
			closeMenu( this, menu, header );
		}
	},

	/**
	 * Toggle sub menus. (When any button.sub-menu-toggle is clicked).
	 *
	 * @param {Event} e
	 */
	handleExpandAppropiateSubMenu: function( e ) {
		e.stopPropagation();

		if ( ! e.currentTarget.nodeName === 'BUTTON' ) {
			return;
		}

		const el = e.currentTarget;
		el.focus();
		navigationHandlers.handleToggleSubMenu( el );
	},

	/**
	 * Handle clicks on submenu toggles.
	 *
	 * @param {Element} toggleBtn - The element clicked on (expecting button.sub-menu-toggle).
	 */
	handleToggleSubMenu( toggleBtn ) {
		// Determine if the button's sub-menu expanded or not?
		const isExpanded = toggleBtn.getAttribute( 'aria-expanded' );

		// Determine if toggleBtn is on the main nav level (not nested)...
		const isOutermost = getIsOutermost( toggleBtn );
		const closestNavEl = toggleBtn.closest( 'nav' );
		if ( isOutermost && closestNavEl ) {
			// 1.Close other sub menus.
			closestNavEl
				.querySelectorAll( '.sub-menu-toggle' )
				.forEach( function( button ) {
					if ( button !== toggleBtn ) {
						button.setAttribute( 'aria-expanded', 'false' );
					}
				} );

			// 2. Remove all all nested (non-visible) links & buttons from tab order.
			removeNavSubItemsFromTabOrder( );
		}

		// If sub menu it is BEING collapsed ie. isExpanded === "false" - Add (only the) next links & buttons inside the relevant sub menu back in to the tab order.
		if ( isExpanded === 'false' ) {
			addSubMenuToTabOrder( toggleBtn );
		}

		// Always toggle this menu. withListeners means also add listeners collapseSubMenuOnClickOutside and to (if aria-expanded is being set to true). If aria-expanded is being set to false, collapseSubMenuOnClickOutside will be removed. toggleAriaExpanded also calls keepSubMenuVisible if opening submenu.
		toggleAriaExpanded( toggleBtn );

		// Listen & close .sub-menu on tab away (leave via <a> or <button>, remove from tabindex & close);
		// so this will be removed IF it fires.
		navigationHandlers.handleCloseSubMenuOnTabAwaySelfRemovingVersion( toggleBtn );

		function addSubMenuToTabOrder( el ) {
			// el is <button>. Get all links in the next ul.sub-menu.
			const allDecendantLinks = el.nextElementSibling.querySelectorAll( 'li a' );

			// Keep only links in the sub-menu that immediately follows el.
			const nextLinks = Array.from( allDecendantLinks ).filter( ( a ) => {
				// ul.sub-menu
				return a.parentElement.parentElement === el.nextElementSibling;
			} );

			// Make these links tabbable while el button.sub-menu is open. These links could may have a drop down button. If so make the sub-menu-toggle tabbable also.
			if ( nextLinks && nextLinks.length ) {
				nextLinks.forEach( ( a ) => {
					if ( a ) {
						a.removeAttribute( 'tabindex' );
						if (
							a.nextElementSibling &&
							a.nextElementSibling.nodeName === 'BUTTON' &&
							a.nextElementSibling.classList.contains( 'sub-menu-toggle' )
						) {
							a.nextElementSibling.removeAttribute( 'tabindex' );
						}
					}
				} );
			}
		}
	},

	/**
	 * Click anywhere to close the mobile menu.
	 */
	handleClickAnywhereToClose() {
		const menu = document.querySelector( '#marie-main-nav' );
		const header = document.getElementById( 'marie-main-header' );
		const toggleBtn = document.querySelector( '.marie-burger-btn' );

		if ( ! toggleBtn || ! menu || ! header || ! menu.classList.contains( 'show' ) ) {
			return;
		}

		closeMenu( toggleBtn, menu, header );
	},

	/**
	 * This is called when a menu is expanded. Listen for tab away.
	 *
	 * @param {Element} subToggleBtn button.sub-menu-toggle.
	 */
	handleCloseSubMenuOnTabAwaySelfRemovingVersion: ( subToggleBtn ) => {
		if ( ! subToggleBtn || ! subToggleBtn.nodeName === 'BUTTON' ) {
			return;
		}

		// Get the last links & the last buttons within subToggleBtn's sub-menu.
		// Note: subToggleBtn.parentNode is li.menu-item-has-children.
		const lastChildLinks = subToggleBtn.parentNode.querySelectorAll( 'ul > li:last-child > a' );
		const lastChildBtns = subToggleBtn.parentNode.querySelectorAll( 'ul > li:last-child > button' );

		// Define handler that removes itself.
		function short( event ) {
			// Return if not tabbing to a different sub menu.
			if ( subToggleBtn.parentNode.contains( event.relatedTarget ) ) {
				return;
			}

			// Close the sub menu.
			subToggleBtn.setAttribute( 'aria-expanded', 'false' );

			// Get non-visible links & buttons inside the closed sub menu.
			const innerLinks = subToggleBtn.parentElement.querySelectorAll( '.sub-menu li a' );
			const innerButtons = subToggleBtn.parentElement.querySelectorAll( '.sub-menu .sub-menu-toggle' );

			// Remove from tab order. add -1 to links that we are leaving.
			if ( innerLinks && innerLinks.length ) {
				innerLinks.forEach( ( a ) => a.setAttribute( 'tabindex', '-1' ) );
			}

			// Remove from tab order. add -1 to buttons that we are leaving.
			if ( innerButtons && innerButtons.length ) {
				innerButtons.forEach( ( a ) => a.setAttribute( 'tabindex', '-1' ) );
			}

			// Remove Liseners. Tab is leaving so no need to keep them.
			lastChildLinks.forEach( ( link ) => link.removeEventListener( 'blur', short, false ) );
			lastChildBtns.forEach( ( btn ) => btn.removeEventListener( 'blur', short, false ) );
		} // end handler

		// 1. Listen for tab away from a menu item link.
		lastChildLinks.forEach( ( link ) => {
			link.addEventListener( 'blur', short, false );
		} );

		// 2. Listen for tab away from a <button.sub-menu-toggle>.
		lastChildBtns.forEach( ( btn ) => {
			btn.addEventListener( 'blur', short, false );
		} );
	},
};
