
/* eslint-disable object-shorthand */

export const navigationUtil = {
	getIsOutermost: function( el ) {
		return el.parentElement.parentElement.id === 'marie-main-menu';
	},

	/**
	 * Change the position of submenus so they always fit the screen horizontally. It's unlikely this would happen without multiple nested submenus
	 *
	 * @param {Element} li - The li element.
	 */
	keepSubMenusVisible: function( li ) {
		const subMenu = li.querySelector( 'ul.sub-menu' );
		if ( ! subMenu ) {
			return;
		}

		const rect = subMenu.getBoundingClientRect();
		const right = Math.round( rect.right );
		const windowWidth = Math.round( window.innerWidth );

		if ( right > windowWidth ) {
			subMenu.classList.add( 'submenu-reposition-right' );
		}
	},

	/**
	 * Toggle a buttons 'aria-expanded' value. toggleAriaExpanded also calls keepSubMenuVisible if opening submenu.
	 *
	 * @param {Element} el - The element.
	 */
	toggleAriaExpanded( el ) {
		if ( ! el || el.nodeName !== 'BUTTON' ) {
			return;
		}

		if ( 'true' !== el.getAttribute( 'aria-expanded' ) ) {
			el.setAttribute( 'aria-expanded', 'true' );

			// If sub-menu is being opened call keepSubMenusVisible.
			navigationUtil.keepSubMenusVisible( el.parentElement );
		} else {
			el.setAttribute( 'aria-expanded', 'false' );
		}
	},

	/**
	 * Close the menu, change necesserary attributes.
	 *
	 * @param {Element} navToggle - Toggle btn.
	 * @param {Element} menu - Nav menu.
	 * @param {Element} header - Header.
	 */
	closeMenu( navToggle, menu, header ) {
		navToggle.classList.remove( 'nav-open' );
		navToggle.setAttribute( 'aria-expanded', false );
		menu.classList.remove( 'show' );
		header.classList.remove( 'nav-open' );
	},

	/**
	 * Open the menu, change necesserary attributes.
	 *
	 * @param {Element} navToggle - Toggle btn.
	 * @param {Element} menu - Nav menu.
	 * @param {Element} header - Header.
	 */
	openMenu( navToggle, menu, header ) {
		navToggle.classList.add( 'nav-open' );
		navToggle.setAttribute( 'aria-expanded', true );
		navToggle.focus();
		menu.classList.add( 'show' );
		header.classList.add( 'nav-open' );
	},

	/**
	 * Removes nav non-visible links & toggle buttons from the tab index.
	 *
	 */
	removeNavSubItemsFromTabOrder() {
		const el = document.querySelector( 'header#marie-main-header #marie-main-menu' );
		if ( ! el ) {
			return;
		}
		navigationUtil.addAllToTabOrder();
		// Get all non-visible links inside main nav.
		const hiddenLinks = el.querySelectorAll( '.menu-item-has-children .sub-menu li a' );

		// Get all non-visible sub-menu-toggle buttons inside main nav.
		const hiddenToggles = el.querySelectorAll( '.menu-item-has-children .sub-menu li button' );

		if ( hiddenLinks && hiddenLinks.length ) {
			hiddenLinks.forEach( ( link ) => link.setAttribute( 'tabindex', '-1' ) );
		}

		if ( hiddenToggles && hiddenToggles.length ) {
			hiddenToggles.forEach( ( toggle ) => toggle.setAttribute( 'tabindex', '-1' ) );
		}
	},

	/**
	 * Determine if we are using the burger btn & slide out nav or not.
	 *
	 * @return {boolean} Is mobile.
	 */
	isMobile() {
		const theHeader = document.querySelector( 'header#marie-main-header' );
		if ( theHeader && theHeader.classList.contains( 'marie-gigantic-menu' ) ) {
			return true;
		}
		return false;
	},

	/**
	 * Inside the main nav, remove all links & buttons from the tab order.
	 */
	removeAllNavItemsFromTabOrder() {
		const el = document.querySelector( 'header#marie-main-header #marie-main-menu' );
		if ( ! el ) {
			return;
		}
		// Get all non-visible links inside main nav.
		const allLinks = el.querySelectorAll( 'ul#marie-main-menu a' );

		// Get all non-visible sub-menu-toggle buttons inside main nav.
		const allToggles = el.querySelectorAll( 'ul#marie-main-menu button' );

		if ( allLinks && allLinks.length ) {
			allLinks.forEach( ( link ) => link.setAttribute( 'tabindex', '-1' ) );
		}

		if ( allToggles && allToggles.length ) {
			allToggles.forEach( ( toggle ) => toggle.setAttribute( 'tabindex', '-1' ) );
		}
	},

	/**
	 * Restore the natural tab order.
	 */
	addAllToTabOrder( ) {
		const el = document.querySelector( 'header#marie-main-header #marie-main-menu' );
		if ( ! el ) {
			return;
		}
		// Get all non-visible links inside main nav.
		const allLinks = el.querySelectorAll( 'ul#marie-main-menu a' );
		// Get all non-visible sub-menu-toggle buttons inside main nav.
		const allToggles = el.querySelectorAll( 'ul#marie-main-menu button' );

		if ( allLinks && allLinks.length ) {
			allLinks.forEach( ( link ) => link.removeAttribute( 'tabindex' ) );
		}

		if ( allToggles && allToggles.length ) {
			allToggles.forEach( ( toggle ) => toggle.removeAttribute( 'tabindex' ) );
		}
	},

	/**
	 * Determine if the mobile menu is open (&visible) or not.
	 */
	isMobileMenuOpen() {
		if ( ! navigationUtil.isMobile() ) {
			return false;
		}
		const burgerBtn = document.querySelector( '.marie-burger-btn' );
		if ( ! burgerBtn ) {
			return false;
		}
		const burgerState = burgerBtn.getAttribute( 'aria-expanded' );
		if ( burgerState && burgerState === 'true' ) {
			return true;
		}
		return false;
	},

	/**
	 * Get the current state of the main nav menu...
	 * STATE 1. Mobile Screen | Menu Closed.
	 * STATE 2. Mobile Screen | Menu Open.
	 * STATE 3. Big Screen ( Menu always Open ).
	 *
	 * @return {string | boolean} 'BIG_SCREEN', 'MOBILE_OPEN', 'MOBILE_CLOSED' or false.
	 */
	getMenuState() {
		const mobile = navigationUtil.isMobile();
		if ( ! mobile ) {
			return 'BIG_SCREEN';
		}
		if ( mobile ) {
			const isOpen = navigationUtil.isMobileMenuOpen();
			if ( isOpen ) {
				return 'MOBILE_OPEN';
			}
			return 'MOBILE_CLOSED';
		}
		return false;
	},
};
